Attribute VB_Name = "ModSHFileInfo"
Option Explicit

' Brought to you by:
'   Brad Martinez
'   btmtz@msn.com
'   btmtz@aol.com
'   http://members.aol.com/btmtz/vb

' ==============================================================
' Definitions were extracted and translated from Shellapi.h found at:
' http://www.microsoft.com/msdn/sdk/platforms/doc/sdk/headers/c236_18.htm

' Descriptions and syntax were extracted from the Win32 SDK found at:
' http://www.microsoft.com/msdn/sdk/platforms/doc/sdk/win32/func/src/f85_2.htm

' Both URLs were valid 06/22/97, the time of this writing.
' ==============================================================

' A word on icon sizes...

' Windows uses four icon sizes: system small, system large, shell small, and shell large.

' The system small icon is displayed in the window caption. To change the size of the
' system small icon, start the Display control panel applet, click the Appearance tab,
' select Caption Buttons from the Item list, then set the Size field. To retrieve the size of
' the system small icon, call the GetSystemMetrics function with SM_CXSMICON and
' SM_CYSMICON.

' The system large icon is mainly used by applications, but it is also displayed in the
' Alt+Tab dialog. The CreateIconFromResource, DrawIcon, ExtractIcon, and LoadIcon
' functions all use system large icons. The size of the system large icon is defined by
' the video driver, therefore it cannot be changed. You can retrieve the size of the system
' large icon by calling GetSystemMetrics with SM_CXICON and SM_CYICON.

' The CreateIcon, CreateIconFromResourceEx, and CreateIconIndirect functions can be
' used to work with icons in sizes other than system large.

' The shell small icon is used in the Windows Explorer and the common dialogs. Currently,
' this defaults to the system small size. To retrieve the size of the shell small icon, use
' the SHGetFileInfo function with SHGFI_SHELLICONSIZE | SHGFI_SMALLICON to
' retrieve the handle of the system image list, then the ImageList_GetIconSize function
' to get the icon size.

' The shell large icon is used on the desktop. To change the size of the large icon, start
' the Display control panel applet, click the Appearance tab, select Icon from the Item list,
' then set the Size field (this size is stored in the registry, under
' HKEY_CURRENT_USER\Control Panel, Desktop\WindowMetrics\Shell Icon Size).
' You must also click the Plus! tab and select the Use large icons check box. To retrieve
' the size of the shell large icon, use the SHGetFileInfo function with SHGFI_SHELLICONSIZE
' to retrieve the handle of the system image list, then the ImageList_GetIconSize function to
' get the icon size.

' The Start menu uses either shell small icons or shell large icons, depending on whether the
' Use large icons check box is selected.
' ==============================================================

' Retrieves information about an object in the file system, such as a file,
' a folder, a directory, or a drive root.
Declare Function SHGetFileInfo Lib "Shell32" Alias "SHGetFileInfoA" _
                              (ByVal pszPath As Any, _
                              ByVal dwFileAttributes As Long, _
                              psfi As SHFILEINFO, _
                              ByVal cbFileInfo As Long, _
                              ByVal uFlags As Long) As Long

' pszPath:
' Pointer to a buffer that contains the path and filename. Both absolute and
' relative paths are valid. If uFlags includes the SHGFI_PIDL, value pszPath
' must be the address of an ITEMIDLIST structure that contains the list of
' item identifiers that uniquely identifies the file within the shell's name space.
' This string can use either short (the 8.3 form) or long filenames.

' dwFileAttributes:
' Array of file attribute flags (FILE_ATTRIBUTE_ values). If uFlags does not
' include the SHGFI_USEFILEATTRIBUTES value, this parameter is ignored.

Public Const FILE_ATTRIBUTE_READONLY = &H1
Public Const FILE_ATTRIBUTE_HIDDEN = &H2
Public Const FILE_ATTRIBUTE_SYSTEM = &H4
Public Const FILE_ATTRIBUTE_DIRECTORY = &H10
Public Const FILE_ATTRIBUTE_ARCHIVE = &H20
Public Const FILE_ATTRIBUTE_NORMAL = &H80
Public Const FILE_ATTRIBUTE_TEMPORARY = &H100
Public Const FILE_ATTRIBUTE_COMPRESSED = &H800

' psfi and cbFileInfo:
' Address and size, in bytes, of the SHFILEINFO structure that receives the file
' information.

' Maximun long filename path length
Public Const MAX_PATH = 260

Type SHFILEINFO   ' shfi
    hIcon As Long
    iIcon As Long
    dwAttributes As Long
    szDisplayName As String * MAX_PATH
    szTypeName As String * 80
End Type

' uFlags:
' Flag that specifies the file information to retrieve. If uFlags includes the SHGFI_ICON
' or SHGFI_SYSICONINDEX value, the return value is the handle to the system image
' list that contains the large icon images. If the SHGFI_SMALLICON value is included
' with SHGFI_ICON or SHGFI_SYSICONINDEX, the return value is the handle to the
' image list that contains the small icon images.

' If uFlags does not include SHGFI_EXETYPE, SHGFI_ICON, SHGFI_SYSICONINDEX,
' or SHGFI_SMALLICON, the return value is nonzero if successful, or zero otherwise.

' This parameter can be a combination of the following values:

' Modifies SHGFI_ICON, causing the function to retrieve the file's large icon.
Public Const SHGFI_LARGEICON = &H0&

' Modifies SHGFI_ICON, causing the function to retrieve the file's small icon.
Public Const SHGFI_SMALLICON = &H1&

' Modifies SHGFI_ICON, causing the function to retrieve the file's open icon. A
' container object displays an open icon to indicate that the container is open.
Public Const SHGFI_OPENICON = &H2&

' Modifies SHGFI_ICON, causing the function to retrieve a shell-sized icon. If
' this flag is not specified, the function sizes the icon according to the system
' metric values.
' The return value is *supposed to be* the handle of the system image list which
' could be passed to the ImageList_GetIconSize function to get the icon size.
' But the return value *is only* nonzero if successful, or zero otherwise.
Public Const SHGFI_SHELLICONSIZE = &H4&

' Indicates that pszPath is the address of an ITEMIDLIST structure rather than
' a path name.
Public Const SHGFI_PIDL = &H8&

' Indicates that the function should not attempt to access the file specified by
' pszPath. Rather, it should act as if the file specified by pszPath exists with
' the file attributes passed in dwFileAttributes. This flag cannot be combined
' with the SHGFI_ATTRIBUTES, SHGFI_EXETYPE, or SHGFI_PIDL flags.
Public Const SHGFI_USEFILEATTRIBUTES = &H10&

' Retrieves the handle of the icon that represents the file and the index of the
' icon within the system image list. The handle is copied to the hIcon member
' of the structure specified by psfi, and the index is copied to the iIcon member.

' The return value is *supposed to be* the handle of the system image list,
' .....boolean instead...!!!
' ** SHGFI_ICON creates a copy of the icon in memory. The DestroyIcon **
' ** function must be called to free any memory the icon occupied.          **
Public Const SHGFI_ICON = &H100&

' Retrieves the display name for the file. The name is copied to the szDisplayName
' member of the structure specified by psfi. The returned display name uses the
' long filename, if any, rather than the 8.3 form of the filename.
Public Const SHGFI_DISPLAYNAME = &H200&

' Retrieves the string that describes the file's type. The string is copied to the
' szTypeName member of the structure specified by psfi.
Public Const SHGFI_TYPENAME = &H400&

' Retrieves the file attribute flags. The flags are copied to the dwAttributes member
' of the structure specified by psfi. See the constants at the end of this file.
Public Const SHGFI_ATTRIBUTES = &H800&

' Retrieves the name of the file that contains the icon representing the file. The
' name is copied to the szDisplayName member of the structure specified by psfi.
Public Const SHGFI_ICONLOCATION = &H1000&

' Returns the type of the executable file if pszPath identifies an executable file.
' To retrieve the executable file type, uFlags must specify only SHGFI_EXETYPE.
' The return value specifies the type of the executable file:
' LowWord value       HighWord value         Type
' 0                                                           Nonexecutable file or an error condition.
' "NE" or "PE"          3.0, 3.5, or 4.0           Windows application
' "MZ"                      0                              MS-DOS .EXE, .COM or .BAT file
' "PE"                      0                              Win32 console application
Public Const SHGFI_EXETYPE = &H2000&

' Constants to represent the strings as ASCII char codes
Public Const EXE_WIN16 = &H454E    ' "NE"
Public Const EXE_DOS16 = &H5A4D  ' "MZ"
Public Const EXE_WIN32 = &H4550    ' "PE"
'Public Const EXE_DOS32 = &H4543   ' "CE"

' Retrieves the index of the icon within the system image list. The index is copied to
' the iIcon member of the structure specified by psfi. The return value is the handle of
' the system image list.
Public Const SHGFI_SYSICONINDEX = &H4000&

' Modifies SHGFI_ICON, causing the function to add the link overlay to the file's icon.
Public Const SHGFI_LINKOVERLAY = &H8000&

' Modifies SHGFI_ICON, causing the function to blend the file's icon with the system
' highlight color.
Public Const SHGFI_SELECTED = &H10000

' ============================================================

' From IShellFolder::GetAttributesOf  (SFGAO)
' The following list the attribute flags that may be returned by SHGFI_ATTRIBUTES.
' File object attributes include capability flags, display attributes, contents flags,
' and miscellaneous attributes.

' Capability flags:
Public Const DROPEFFECT_COPY = 1
Public Const DROPEFFECT_MOVE = 2
Public Const DROPEFFECT_LINK = 4
Public Const SFGAO_CANCOPY = DROPEFFECT_COPY   ' // Objects can be copied
Public Const SFGAO_CANMOVE = DROPEFFECT_MOVE  ' // Objects can be moved
Public Const SFGAO_CANLINK = DROPEFFECT_LINK        ' // Objects can have shortcuts
Public Const SFGAO_CANRENAME = &H10&                     ' // Objects can be renamed
Public Const SFGAO_CANDELETE = &H20&                       ' // Objects can be deleted
Public Const SFGAO_HASPROPSHEET = &H40&               ' // Objects have property sheets
Public Const SFGAO_DROPTARGET = &H100&                  ' // Objects are drop target
Public Const SFGAO_CAPABILITYMASK = &H177&            ' // Mask for the capability flags

' Display attributes:
Public Const SFGAO_LINK = &H10000                          ' // Is a shortcut (link)
Public Const SFGAO_SHARE = &H20000                      ' // Is shared
Public Const SFGAO_READONLY = &H40000                ' // Is read-only
Public Const SFGAO_GHOSTED = &H80000                  ' // Is ghosted icon
Public Const SFGAO_DISPLAYATTRMASK = &HF0000  ' // Mask for the display attributes.

' Contents attributes (flags):
Public Const SFGAO_FILESYSANCESTOR = &H10000000   ' // Contains file a system folder
Public Const SFGAO_FOLDER = &H20000000                     ' // Is a folder.
Public Const SFGAO_FILESYSTEM = &H40000000              ' // Is a file system object (file/folder/root)
Public Const SFGAO_HASSUBFOLDER = &H80000000        ' // Expandable in the map pane
Public Const SFGAO_CONTENTSMASK = &H80000000       ' // Mask for contents attributes

' Miscellaneous attributes:
Public Const SFGAO_VALIDATE = &H1000000           ' // invalidate cached information
Public Const SFGAO_REMOVABLE = &H2000000      ' // Is removeable media
Public Const SFGAO_COMPRESSED = &H4000000   ' // Object is compressed (use alt color)
